#!/bin/sh

export LD_LIBRARY_PATH=/opt/unigine-tropics/bin:$LD_LIBRARY_PATH
/opt/unigine-tropics/bin/Tropics		-video_app opengl \
					-sound_app openal \
					-extern_define RELEASE \
					-system_script tropics/unigine.cpp \
					-engine_config ../data/unigine.cfg \
					-data_path ../ \
					-video_fullscreen 1 \
					-video_mode -1 \
					-video_width 1920 \
					-video_height 1080
